@@ -10,7 +10,7 @@ impl Command for EachWhile {
     }
 
     fn usage(&self) -> &str {
-        "Run a block on each row of the input list until a null is found, then create a new list with the results."
+        "Run a closure on each row of the input list until a null is found, then create a new list with the results."
     }
 
     fn search_terms(&self) -> Vec<&str> {
@@ -78,37 +78,39 @@ impl Command for EachWhile {
             | PipelineData::ListStream(..) => {
                 let mut closure = ClosureEval::new(engine_state, stack, closure);
                 Ok(input
-                    .into_iter()
-                    .map_while(move |value| match closure.run_with_value(value) {
-                        Ok(data) => {
-                            let value = data.into_value(head);
-                            (!value.is_nothing()).then_some(value)
-                        }
-                        Err(_) => None,
-                    })
-                    .fuse()
-                    .into_pipeline_data(engine_state.ctrlc.clone()))
-            }
-            PipelineData::ExternalStream { stdout: None, .. } => Ok(PipelineData::empty()),
-            PipelineData::ExternalStream {
-                stdout: Some(stream),
-                ..
-            } => {
-                let mut closure = ClosureEval::new(engine_state, stack, closure);
-                Ok(stream
                     .into_iter()
                     .map_while(move |value| {
-                        let value = value.ok()?;
-                        match closure.run_with_value(value) {
-                            Ok(data) => {
-                                let value = data.into_value(head);
-                                (!value.is_nothing()).then_some(value)
-                            }
+                        match closure
+                            .run_with_value(value)
+                            .and_then(|data| data.into_value(head))
+                        {
+                            Ok(value) => (!value.is_nothing()).then_some(value),
                             Err(_) => None,
                         }
                     })
                     .fuse()
-                    .into_pipeline_data(engine_state.ctrlc.clone()))
+                    .into_pipeline_data(head, engine_state.ctrlc.clone()))
+            }
+            PipelineData::ByteStream(stream, ..) => {
+                let span = stream.span();
+                if let Some(chunks) = stream.chunks() {
+                    let mut closure = ClosureEval::new(engine_state, stack, closure);
+                    Ok(chunks
+                        .map_while(move |value| {
+                            let value = value.ok()?;
+                            match closure
+                                .run_with_value(value)
+                                .and_then(|data| data.into_value(span))
+                            {
+                                Ok(value) => (!value.is_nothing()).then_some(value),
+                                Err(_) => None,
+                            }
+                        })
+                        .fuse()
+                        .into_pipeline_data(head, engine_state.ctrlc.clone()))
+                } else {
+                    Ok(PipelineData::Empty)
+                }
             }
             // This match allows non-iterables to be accepted,
             // which is currently considered undesirable (Nov 2022).
