@@ -5,13 +5,8 @@ mod sinh;
 mod tan;
 mod tanh;
 
-mod egamma;
-mod euler;
 mod exp;
 mod ln;
-mod phi;
-mod pi;
-mod tau;
 
 mod arccos;
 mod arccosh;
@@ -27,13 +22,8 @@ pub use sinh::SubCommand as MathSinH;
 pub use tan::SubCommand as MathTan;
 pub use tanh::SubCommand as MathTanH;
 
-pub use egamma::SubCommand as MathEulerGamma;
-pub use euler::SubCommand as MathEuler;
 pub use exp::SubCommand as MathExp;
 pub use ln::SubCommand as MathLn;
-pub use phi::SubCommand as MathPhi;
-pub use pi::SubCommand as MathPi;
-pub use tau::SubCommand as MathTau;
 
 pub use arccos::SubCommand as MathArcCos;
 pub use arccosh::SubCommand as MathArcCosH;
