@@ -1,8 +1,5 @@
 use nu_cmd_base::input_handler::{operate as general_operate, CmdArgument};
-use nu_engine::CallExt;
-use nu_protocol::ast::{Call, CellPath};
-use nu_protocol::engine::{EngineState, Stack};
-use nu_protocol::{PipelineData, ShellError, Span, Value};
+use nu_engine::command_prelude::*;
 
 enum HexDecodingError {
     InvalidLength(usize),
