@@ -1,5 +1,5 @@
 use nu_engine::command_prelude::*;
-use nu_protocol::{engine::StateWorkingSet, PipelineMetadata};
+use nu_protocol::{engine::StateWorkingSet, ByteStreamSource, PipelineMetadata};
 
 #[derive(Clone)]
 pub struct Describe;
@@ -26,7 +26,6 @@ impl Command for Describe {
                 "show detailed information about the value",
                 Some('d'),
             )
-            .switch("collect-lazyrecords", "collect lazy records", Some('l'))
             .category(Category::Core)
     }
 
@@ -44,21 +43,7 @@ impl Command for Describe {
         let options = Options {
             no_collect: call.has_flag(engine_state, stack, "no-collect")?,
             detailed: call.has_flag(engine_state, stack, "detailed")?,
-            collect_lazyrecords: call.has_flag(engine_state, stack, "collect-lazyrecords")?,
         };
-        if options.collect_lazyrecords {
-            nu_protocol::report_error_new(
-                engine_state,
-                &ShellError::GenericError {
-                    error: "Deprecated flag".into(),
-                    msg: "the `--collect-lazyrecords` flag is deprecated, since lazy records will be removed in 0.94.0"
-                        .into(),
-                    span: Some(call.head),
-                    help: None,
-                    inner: vec![],
-                },
-            );
-        }
         run(Some(engine_state), call, input, options)
     }
 
@@ -71,7 +56,6 @@ impl Command for Describe {
         let options = Options {
             no_collect: call.has_flag_const(working_set, "no-collect")?,
             detailed: call.has_flag_const(working_set, "detailed")?,
-            collect_lazyrecords: call.has_flag_const(working_set, "collect-lazyrecords")?,
         };
         run(None, call, input, options)
     }
@@ -89,13 +73,11 @@ impl Command for Describe {
                     "{shell:'true', uwu:true, features: {bugs:false, multiplatform:true, speed: 10}, fib: [1 1 2 3 5 8], on_save: {|x| print $'Saving ($x)'}, first_commit: 2019-05-10, my_duration: (4min + 20sec)} | describe -d",
                 result: Some(Value::test_record(record!(
                     "type" => Value::test_string("record"),
-                    "lazy" => Value::test_bool(false),
                     "columns" => Value::test_record(record!(
                         "shell" => Value::test_string("string"),
                         "uwu" => Value::test_string("bool"),
                         "features" => Value::test_record(record!(
                             "type" => Value::test_string("record"),
-                            "lazy" => Value::test_bool(false),
                             "columns" => Value::test_record(record!(
                                 "bugs" => Value::test_string("bool"),
                                 "multiplatform" => Value::test_string("bool"),
@@ -168,7 +150,6 @@ impl Command for Describe {
 struct Options {
     no_collect: bool,
     detailed: bool,
-    collect_lazyrecords: bool,
 }
 
 fn run(
@@ -177,127 +158,103 @@ fn run(
     input: PipelineData,
     options: Options,
 ) -> Result<PipelineData, ShellError> {
-    let metadata = input.metadata().clone().map(Box::new);
     let head = call.head;
+    let metadata = input.metadata();
+
+    let description = match input {
+        PipelineData::ByteStream(stream, ..) => {
+            let type_ = stream.type_().describe();
+
+            let description = if options.detailed {
+                let origin = match stream.source() {
+                    ByteStreamSource::Read(_) => "unknown",
+                    ByteStreamSource::File(_) => "file",
+                    ByteStreamSource::Child(_) => "external",
+                };
 
-    let description: Value = match input {
-        PipelineData::ExternalStream {
-            ref stdout,
-            ref stderr,
-            ref exit_code,
-            ..
-        } => {
-            if options.detailed {
                 Value::record(
-                    record!(
-                        "type" => Value::string("stream", head),
-                        "origin" => Value::string("external", head),
-                        "stdout" => match stdout {
-                            Some(_) => Value::record(
-                                    record!(
-                                        "type" => Value::string("stream", head),
-                                        "origin" => Value::string("external", head),
-                                        "subtype" => Value::string("any", head),
-                                    ),
-                                    head,
-                                ),
-                            None => Value::nothing(head),
-                        },
-                        "stderr" => match stderr {
-                            Some(_) => Value::record(
-                                    record!(
-                                        "type" => Value::string("stream", head),
-                                        "origin" => Value::string("external", head),
-                                        "subtype" => Value::string("any", head),
-                                    ),
-                                    head,
-                                ),
-                            None => Value::nothing(head),
-                        },
-                        "exit_code" => match exit_code {
-                            Some(_) => Value::record(
-                                    record!(
-                                        "type" => Value::string("stream", head),
-                                        "origin" => Value::string("external", head),
-                                        "subtype" => Value::string("int", head),
-                                    ),
-                                    head,
-                                ),
-                            None => Value::nothing(head),
-                        },
+                    record! {
+                        "type" => Value::string(type_, head),
+                        "origin" => Value::string(origin, head),
                         "metadata" => metadata_to_value(metadata, head),
-                    ),
+                    },
                     head,
                 )
             } else {
-                Value::string("raw input", head)
+                Value::string(type_, head)
+            };
+
+            if !options.no_collect {
+                stream.drain()?;
             }
+
+            description
         }
-        PipelineData::ListStream(_, _) => {
+        PipelineData::ListStream(stream, ..) => {
             if options.detailed {
+                let subtype = if options.no_collect {
+                    Value::string("any", head)
+                } else {
+                    describe_value(stream.into_value(), head, engine_state)
+                };
                 Value::record(
-                    record!(
+                    record! {
                         "type" => Value::string("stream", head),
                         "origin" => Value::string("nushell", head),
-                        "subtype" => {
-                           if options.no_collect {
-                            Value::string("any", head)
-                           } else {
-                            describe_value(input.into_value(head), head, engine_state, options)?
-                           }
-                        },
+                        "subtype" => subtype,
                         "metadata" => metadata_to_value(metadata, head),
-                    ),
+                    },
                     head,
                 )
             } else if options.no_collect {
                 Value::string("stream", head)
             } else {
-                let value = input.into_value(head);
+                let value = stream.into_value();
                 let base_description = value.get_type().to_string();
-
                 Value::string(format!("{} (stream)", base_description), head)
             }
         }
-        _ => {
-            let value = input.into_value(head);
+        PipelineData::Value(value, ..) => {
             if !options.detailed {
                 Value::string(value.get_type().to_string(), head)
             } else {
-                describe_value(value, head, engine_state, options)?
+                describe_value(value, head, engine_state)
             }
         }
+        PipelineData::Empty => Value::string(Type::Nothing.to_string(), head),
     };
 
     Ok(description.into_pipeline_data())
 }
 
-fn compact_primitive_description(mut value: Value) -> Value {
-    if let Value::Record { ref mut val, .. } = value {
-        if val.len() != 1 {
-            return value;
-        }
-        if let Some(type_name) = val.to_mut().get_mut("type") {
-            return std::mem::take(type_name);
-        }
-    }
-    value
+enum Description {
+    String(String),
+    Record(Record),
 }
 
-fn describe_value(
+impl Description {
+    fn into_value(self, span: Span) -> Value {
+        match self {
+            Description::String(ty) => Value::string(ty, span),
+            Description::Record(record) => Value::record(record, span),
+        }
+    }
+}
+
+fn describe_value(value: Value, head: Span, engine_state: Option<&EngineState>) -> Value {
+    let record = match describe_value_inner(value, head, engine_state) {
+        Description::String(ty) => record! { "type" => Value::string(ty, head) },
+        Description::Record(record) => record,
+    };
+    Value::record(record, head)
+}
+
+fn describe_value_inner(
     value: Value,
-    head: nu_protocol::Span,
+    head: Span,
     engine_state: Option<&EngineState>,
-    options: Options,
-) -> Result<Value, ShellError> {
-    Ok(match value {
-        Value::Custom { val, .. } => Value::record(
-            record!(
-                "type" => Value::string("custom", head),
-                "subtype" => Value::string(val.type_name(), head),
-            ),
-            head,
-        ),
+) -> Description {
+    match value {
         Value::Bool { .. }
         | Value::Int { .. }
         | Value::Float { .. }
@@ -307,140 +264,74 @@ fn describe_value(
         | Value::Range { .. }
         | Value::String { .. }
         | Value::Glob { .. }
-        | Value::Nothing { .. } => Value::record(
-            record!(
-                "type" => Value::string(value.get_type().to_string(), head),
-            ),
-            head,
-        ),
+        | Value::Nothing { .. } => Description::String(value.get_type().to_string()),
         Value::Record { val, .. } => {
-            let mut val = val.into_owned();
-            for (_k, v) in val.iter_mut() {
-                *v = compact_primitive_description(describe_value(
-                    std::mem::take(v),
-                    head,
-                    engine_state,
-                    options,
-                )?);
+            let mut columns = val.into_owned();
+            for (_, val) in &mut columns {
+                *val =
+                    describe_value_inner(std::mem::take(val), head, engine_state).into_value(head);
             }
 
-            Value::record(
-                record!(
-                    "type" => Value::string("record", head),
-                    "lazy" => Value::bool(false, head),
-                    "columns" => Value::record(val, head),
-                ),
-                head,
-            )
+            Description::Record(record! {
+                "type" => Value::string("record", head),
+                "columns" => Value::record(columns, head),
+            })
         }
-        Value::List { vals, .. } => Value::record(
-            record!(
+        Value::List { mut vals, .. } => {
+            for val in &mut vals {
+                *val =
+                    describe_value_inner(std::mem::take(val), head, engine_state).into_value(head);
+            }
+
+            Description::Record(record! {
                 "type" => Value::string("list", head),
                 "length" => Value::int(vals.len() as i64, head),
-                "values" => Value::list(vals.into_iter().map(|v|
-                    Ok(compact_primitive_description(
-                        describe_value(v, head, engine_state, options)?
-                    ))
-                )
-                .collect::<Result<Vec<Value>, ShellError>>()?, head),
-            ),
-            head,
-        ),
+                "values" => Value::list(vals, head),
+            })
+        }
         Value::Closure { val, .. } => {
             let block = engine_state.map(|engine_state| engine_state.get_block(val.block_id));
 
+            let mut record = record! { "type" => Value::string("closure", head) };
             if let Some(block) = block {
-                let mut record = Record::new();
-                record.push("type", Value::string("closure", head));
                 record.push(
                     "signature",
                     Value::record(
-                        record!(
+                        record! {
                             "name" => Value::string(block.signature.name.clone(), head),
                             "category" => Value::string(block.signature.category.to_string(), head),
-                        ),
+                        },
                         head,
                     ),
                 );
-                Value::record(record, head)
-            } else {
-                Value::record(
-                    record!(
-                        "type" => Value::string("closure", head),
-                    ),
-                    head,
-                )
             }
+            Description::Record(record)
         }
-
-        Value::Error { error, .. } => Value::record(
-            record!(
-                "type" => Value::string("error", head),
-                "subtype" => Value::string(error.to_string(), head),
-            ),
-            head,
-        ),
-        Value::Binary { val, .. } => Value::record(
-            record!(
-                "type" => Value::string("binary", head),
-                "length" => Value::int(val.len() as i64, head),
-            ),
-            head,
-        ),
-        Value::CellPath { val, .. } => Value::record(
-            record!(
-                "type" => Value::string("cellpath", head),
-                "length" => Value::int(val.members.len() as i64, head),
-            ),
-            head,
-        ),
-        Value::LazyRecord { val, .. } => {
-            let mut record = Record::new();
-
-            record.push("type", Value::string("record", head));
-            record.push("lazy", Value::bool(true, head));
-
-            if options.collect_lazyrecords {
-                let collected = val.collect()?;
-                if let Value::Record { val, .. } =
-                    describe_value(collected, head, engine_state, options)?
-                {
-                    let mut val = Record::clone(&val);
-
-                    for (_k, v) in val.iter_mut() {
-                        *v = compact_primitive_description(describe_value(
-                            std::mem::take(v),
-                            head,
-                            engine_state,
-                            options,
-                        )?);
-                    }
-
-                    record.push("length", Value::int(val.len() as i64, head));
-                    record.push("columns", Value::record(val, head));
-                } else {
-                    let cols = val.column_names();
-                    record.push("length", Value::int(cols.len() as i64, head));
-                }
-            } else {
-                let cols = val.column_names();
-                record.push("length", Value::int(cols.len() as i64, head));
-            }
-
-            Value::record(record, head)
-        }
-    })
+        Value::Error { error, .. } => Description::Record(record! {
+            "type" => Value::string("error", head),
+            "subtype" => Value::string(error.to_string(), head),
+        }),
+        Value::Binary { val, .. } => Description::Record(record! {
+            "type" => Value::string("binary", head),
+            "length" => Value::int(val.len() as i64, head),
+        }),
+        Value::CellPath { val, .. } => Description::Record(record! {
+            "type" => Value::string("cell-path", head),
+            "length" => Value::int(val.members.len() as i64, head),
+        }),
+        Value::Custom { val, .. } => Description::Record(record! {
+            "type" => Value::string("custom", head),
+            "subtype" => Value::string(val.type_name(), head),
+        }),
+    }
 }
 
-fn metadata_to_value(metadata: Option<Box<PipelineMetadata>>, head: nu_protocol::Span) -> Value {
-    match metadata {
-        Some(metadata) => Value::record(
-            record!(
-                "data_source" => Value::string(format!("{:?}", metadata.data_source), head),
-            ),
-            head,
-        ),
-        _ => Value::nothing(head),
+fn metadata_to_value(metadata: Option<PipelineMetadata>, head: Span) -> Value {
+    if let Some(metadata) = metadata {
+        let data_source = Value::string(format!("{:?}", metadata.data_source), head);
+        Value::record(record! { "data_source" => data_source }, head)
+    } else {
+        Value::nothing(head)
     }
 }
 
