@@ -1,13 +1,8 @@
-use std::path::PathBuf;
-
 use nu_engine::{
-    eval_block_with_early_return, find_in_dirs_env, get_dirs_var_from_call, redirect_env, CallExt,
-};
-use nu_protocol::ast::Call;
-use nu_protocol::engine::{Command, EngineState, Stack};
-use nu_protocol::{
-    Category, Example, PipelineData, ShellError, Signature, Spanned, SyntaxShape, Type, Value,
+    command_prelude::*, find_in_dirs_env, get_dirs_var_from_call, get_eval_block_with_early_return,
+    redirect_env,
 };
+use std::path::PathBuf;
 
 /// Source a file for environment variables.
 #[derive(Clone)]
@@ -74,16 +69,13 @@ impl Command for SourceEnv {
 
         // Evaluate the block
         let block = engine_state.get_block(block_id as usize).clone();
-        let mut callee_stack = caller_stack.gather_captures(engine_state, &block.captures);
+        let mut callee_stack = caller_stack
+            .gather_captures(engine_state, &block.captures)
+            .reset_pipes();
 
-        let result = eval_block_with_early_return(
-            engine_state,
-            &mut callee_stack,
-            &block,
-            input,
-            call.redirect_stdout,
-            call.redirect_stderr,
-        );
+        let eval_block_with_early_return = get_eval_block_with_early_return(engine_state);
+
+        let result = eval_block_with_early_return(engine_state, &mut callee_stack, &block, input);
 
         // Merge the block's environment to the current stack
         redirect_env(engine_state, caller_stack, &callee_stack);
