@@ -50,9 +50,9 @@ impl Command for Enumerate {
         call: &Call,
         input: PipelineData,
     ) -> Result<PipelineData, ShellError> {
+        let head = call.head;
         let metadata = input.metadata();
         let ctrlc = engine_state.ctrlc.clone();
-        let span = call.head;
 
         Ok(input
             .into_iter()
@@ -60,13 +60,13 @@ impl Command for Enumerate {
             .map(move |(idx, x)| {
                 Value::record(
                     record! {
-                        "index" => Value::int(idx as i64, span),
+                        "index" => Value::int(idx as i64, head),
                         "item" => x,
                     },
-                    span,
+                    head,
                 )
             })
-            .into_pipeline_data_with_metadata(metadata, ctrlc))
+            .into_pipeline_data_with_metadata(head, ctrlc, metadata))
     }
 }
 
