@@ -81,10 +81,11 @@ impl Command for TakeUntil {
             .take_while(move |value| {
                 closure
                     .run_with_value(value.clone())
-                    .map(|data| data.into_value(head).is_false())
+                    .and_then(|data| data.into_value(head))
+                    .map(|cond| cond.is_false())
                     .unwrap_or(false)
             })
-            .into_pipeline_data_with_metadata(metadata, engine_state.ctrlc.clone()))
+            .into_pipeline_data_with_metadata(head, engine_state.ctrlc.clone(), metadata))
     }
 }
 
