@@ -42,9 +42,9 @@ impl Command for Wrap {
             | PipelineData::ListStream { .. } => Ok(input
                 .into_iter()
                 .map(move |x| Value::record(record! { name.clone() => x }, span))
-                .into_pipeline_data_with_metadata(metadata, engine_state.ctrlc.clone())),
-            PipelineData::ExternalStream { .. } => Ok(Value::record(
-                record! { name => input.into_value(call.head) },
+                .into_pipeline_data_with_metadata(span, engine_state.ctrlc.clone(), metadata)),
+            PipelineData::ByteStream(stream, ..) => Ok(Value::record(
+                record! { name => stream.into_value()? },
                 span,
             )
             .into_pipeline_data_with_metadata(metadata)),
