@@ -1,3 +1,5 @@
+use std::sync::Arc;
+
 use crate::formats::to::delimited::to_delimited_data;
 use nu_engine::command_prelude::*;
 use nu_protocol::Config;
@@ -27,26 +29,37 @@ impl Command for ToCsv {
                 "do not output the columns names as the first row",
                 Some('n'),
             )
+            .named(
+                "columns",
+                SyntaxShape::List(SyntaxShape::String.into()),
+                "the names (in order) of the columns to use",
+                None,
+            )
             .category(Category::Formats)
     }
 
     fn examples(&self) -> Vec<Example> {
         vec![
             Example {
-                description: "Outputs an CSV string representing the contents of this table",
+                description: "Outputs a CSV string representing the contents of this table",
                 example: "[[foo bar]; [1 2]] | to csv",
                 result: Some(Value::test_string("foo,bar\n1,2\n")),
             },
             Example {
-                description: "Outputs an CSV string representing the contents of this table",
+                description: "Outputs a CSV string representing the contents of this table",
                 example: "[[foo bar]; [1 2]] | to csv --separator ';' ",
                 result: Some(Value::test_string("foo;bar\n1;2\n")),
             },
             Example {
-                description: "Outputs an CSV string representing the contents of this record",
+                description: "Outputs a CSV string representing the contents of this record",
                 example: "{a: 1 b: 2} | to csv",
                 result: Some(Value::test_string("a,b\n1,2\n")),
             },
+            Example {
+                description: "Outputs a CSV stream with column names pre-determined",
+                example: "[[foo bar baz]; [1 2 3]] | to csv --columns [baz foo]",
+                result: Some(Value::test_string("baz,foo\n3,1\n")),
+            },
         ]
     }
 
@@ -64,8 +77,9 @@ impl Command for ToCsv {
         let head = call.head;
         let noheaders = call.has_flag(engine_state, stack, "noheaders")?;
         let separator: Option<Spanned<String>> = call.get_flag(engine_state, stack, "separator")?;
-        let config = engine_state.get_config();
-        to_csv(input, noheaders, separator, head, config)
+        let columns: Option<Vec<String>> = call.get_flag(engine_state, stack, "columns")?;
+        let config = engine_state.config.clone();
+        to_csv(input, noheaders, separator, columns, head, config)
     }
 }
 
@@ -73,13 +87,14 @@ fn to_csv(
     input: PipelineData,
     noheaders: bool,
     separator: Option<Spanned<String>>,
+    columns: Option<Vec<String>>,
     head: Span,
-    config: &Config,
+    config: Arc<Config>,
 ) -> Result<PipelineData, ShellError> {
     let sep = match separator {
         Some(Spanned { item: s, span, .. }) => {
             if s == r"\t" {
-                '\t'
+                Spanned { item: '\t', span }
             } else {
                 let vec_s: Vec<char> = s.chars().collect();
                 if vec_s.len() != 1 {
@@ -89,13 +104,19 @@ fn to_csv(
                         span,
                     });
                 };
-                vec_s[0]
+                Spanned {
+                    item: vec_s[0],
+                    span: head,
+                }
             }
         }
-        _ => ',',
+        _ => Spanned {
+            item: ',',
+            span: head,
+        },
     };
 
-    to_delimited_data(noheaders, sep, "CSV", input, head, config)
+    to_delimited_data(noheaders, sep, columns, "CSV", input, head, config)
 }
 
 #[cfg(test)]
