@@ -1,9 +1,4 @@
-use nu_engine::CallExt;
-use nu_protocol::engine::{Command, EngineState, Stack};
-use nu_protocol::{
-    ast::Call, Category, Example, IntoPipelineData, PipelineData, ShellError, Signature, Span,
-    Spanned, SyntaxShape, Type, Value,
-};
+use nu_engine::command_prelude::*;
 
 #[derive(Clone)]
 pub struct SeqChar;
