@@ -14,7 +14,7 @@ impl Command for Panic {
 
     fn signature(&self) -> nu_protocol::Signature {
         Signature::build("panic")
-            .input_output_types(vec![(Type::Nothing, Type::Table(vec![]))])
+            .input_output_types(vec![(Type::Nothing, Type::table())])
             // LsGlobPattern is similar to string, it won't auto-expand
             // and we use it to track if the user input is quoted.
             .optional("msg", SyntaxShape::String, "The glob pattern to use.")
