@@ -660,7 +660,7 @@ Operating system commands:
         let ctrlc = engine_state.ctrlc.clone();
 
         if list {
-            return generate_ansi_code_list(ctrlc, call.head, use_ansi_coloring);
+            return Ok(generate_ansi_code_list(ctrlc, call.head, use_ansi_coloring));
         }
 
         // The code can now be one of the ansi abbreviations like green_bold
@@ -694,7 +694,7 @@ Operating system commands:
         let ctrlc = working_set.permanent().ctrlc.clone();
 
         if list {
-            return generate_ansi_code_list(ctrlc, call.head, use_ansi_coloring);
+            return Ok(generate_ansi_code_list(ctrlc, call.head, use_ansi_coloring));
         }
 
         // The code can now be one of the ansi abbreviations like green_bold
@@ -784,10 +784,7 @@ fn heavy_lifting(code: Value, escape: bool, osc: bool, call: &Call) -> Result<St
                 None => {
                     return Err(ShellError::TypeMismatch {
                         err_message: String::from("Unknown ansi code"),
-                        span: call
-                            .positional_nth(0)
-                            .expect("Unexpected missing argument")
-                            .span,
+                        span: code.span(),
                     })
                 }
             }
@@ -833,8 +830,8 @@ fn generate_ansi_code_list(
     ctrlc: Option<Arc<AtomicBool>>,
     call_span: Span,
     use_ansi_coloring: bool,
-) -> Result<PipelineData, ShellError> {
-    return Ok(CODE_LIST
+) -> PipelineData {
+    CODE_LIST
         .iter()
         .enumerate()
         .map(move |(i, ansi_code)| {
@@ -865,7 +862,7 @@ fn generate_ansi_code_list(
 
             Value::record(record, call_span)
         })
-        .into_pipeline_data(ctrlc));
+        .into_pipeline_data(call_span, ctrlc)
 }
 
 fn build_ansi_hashmap(v: &[AnsiCode]) -> HashMap<&str, &str> {
