@@ -1,11 +1,6 @@
 use nix::sys::resource::{rlim_t, Resource, RLIM_INFINITY};
-use nu_engine::CallExt;
-use nu_protocol::{
-    ast::Call,
-    engine::{Command, EngineState, Stack},
-    Category, Example, IntoPipelineData, PipelineData, Record, ShellError, Signature, Span,
-    SyntaxShape, Type, Value,
-};
+use nu_engine::command_prelude::*;
+
 use once_cell::sync::Lazy;
 
 /// An object contains resource related parameters
