@@ -1,4 +1,5 @@
 use nu_engine::command_prelude::*;
+use std::io::Write;
 
 #[derive(Clone)]
 pub struct StrJoin;
@@ -40,31 +41,40 @@ impl Command for StrJoin {
     ) -> Result<PipelineData, ShellError> {
         let separator: Option<String> = call.opt(engine_state, stack, 0)?;
 
-        let config = engine_state.get_config();
+        let config = engine_state.config.clone();
 
-        // let output = input.collect_string(&separator.unwrap_or_default(), &config)?;
-        // Hmm, not sure what we actually want.
-        // `to_formatted_string` formats dates as human readable which feels funny.
-        let mut strings: Vec<String> = vec![];
+        let span = call.head;
 
-        for value in input {
-            let str = match value {
-                Value::Error { error, .. } => {
-                    return Err(*error);
+        let metadata = input.metadata();
+        let mut iter = input.into_iter();
+        let mut first = true;
+
+        let output = ByteStream::from_fn(span, None, ByteStreamType::String, move |buffer| {
+            // Write each input to the buffer
+            if let Some(value) = iter.next() {
+                // Write the separator if this is not the first
+                if first {
+                    first = false;
+                } else if let Some(separator) = &separator {
+                    write!(buffer, "{}", separator)?;
                 }
-                Value::Date { val, .. } => format!("{val:?}"),
-                value => value.to_expanded_string("\n", config),
-            };
-            strings.push(str);
-        }
 
-        let output = if let Some(separator) = separator {
-            strings.join(&separator)
-        } else {
-            strings.join("")
-        };
+                match value {
+                    Value::Error { error, .. } => {
+                        return Err(*error);
+                    }
+                    // Hmm, not sure what we actually want.
+                    // `to_expanded_string` formats dates as human readable which feels funny.
+                    Value::Date { val, .. } => write!(buffer, "{val:?}")?,
+                    value => write!(buffer, "{}", value.to_expanded_string("\n", &config))?,
+                }
+                Ok(true)
+            } else {
+                Ok(false)
+            }
+        });
 
-        Ok(Value::string(output, call.head).into_pipeline_data())
+        Ok(PipelineData::ByteStream(output, metadata))
     }
 
     fn examples(&self) -> Vec<Example> {
