@@ -2,7 +2,6 @@ mod case;
 mod contains;
 mod distance;
 mod ends_with;
-mod escape_glob;
 mod expand;
 mod index_of;
 mod join;
@@ -18,7 +17,6 @@ pub use case::*;
 pub use contains::SubCommand as StrContains;
 pub use distance::SubCommand as StrDistance;
 pub use ends_with::SubCommand as StrEndswith;
-pub use escape_glob::SubCommand as StrEscapeGlob;
 pub use expand::SubCommand as StrExpand;
 pub use index_of::SubCommand as StrIndexOf;
 pub use join::*;
