@@ -5,15 +5,22 @@
 use lscolors::{LsColors, Style};
 use nu_color_config::{color_from_hex, StyleComputer, TextStyle};
 use nu_engine::{command_prelude::*, env::get_config, env_to_string};
-use nu_protocol::{Config, DataSource, ListStream, PipelineMetadata, RawStream, TableMode};
+use nu_pretty_hex::HexConfig;
+use nu_protocol::{
+    ByteStream, Config, DataSource, ListStream, PipelineMetadata, TableMode, ValueIterator,
+};
 use nu_table::{
     common::create_nu_table_config, CollapsedTable, ExpandedTable, JustTable, NuTable, NuTableCell,
     StringResult, TableOpts, TableOutput,
 };
 use nu_utils::get_ls_colors;
 use std::{
-    collections::VecDeque, io::IsTerminal, path::PathBuf, str::FromStr, sync::atomic::AtomicBool,
-    sync::Arc, time::Instant,
+    collections::VecDeque,
+    io::{IsTerminal, Read},
+    path::PathBuf,
+    str::FromStr,
+    sync::{atomic::AtomicBool, Arc},
+    time::Instant,
 };
 use terminal_size::{Height, Width};
 use url::Url;
@@ -358,30 +365,23 @@ fn handle_table_command(
 ) -> Result<PipelineData, ShellError> {
     let span = input.data.span().unwrap_or(input.call.head);
     match input.data {
-        PipelineData::ExternalStream { .. } => Ok(input.data),
+        // Binary streams should behave as if they really are `binary` data, and printed as hex
+        PipelineData::ByteStream(stream, _) if stream.type_() == ByteStreamType::Binary => Ok(
+            PipelineData::ByteStream(pretty_hex_stream(stream, input.call.head), None),
+        ),
+        PipelineData::ByteStream(..) => Ok(input.data),
         PipelineData::Value(Value::Binary { val, .. }, ..) => {
-            let bytes = format!("{}\n", nu_pretty_hex::pretty_hex(&val)).into_bytes();
             let ctrlc = input.engine_state.ctrlc.clone();
-            let stream = RawStream::new(
-                Box::new([Ok(bytes)].into_iter()),
-                ctrlc,
-                input.call.head,
+            let stream = ByteStream::read_binary(val, input.call.head, ctrlc);
+            Ok(PipelineData::ByteStream(
+                pretty_hex_stream(stream, input.call.head),
                 None,
-            );
-
-            Ok(PipelineData::ExternalStream {
-                stdout: Some(stream),
-                stderr: None,
-                exit_code: None,
-                span: input.call.head,
-                metadata: None,
-                trim_end_newline: false,
-            })
+            ))
         }
         // None of these two receive a StyleComputer because handle_row_stream() can produce it by itself using engine_state and stack.
         PipelineData::Value(Value::List { vals, .. }, metadata) => {
             let ctrlc = input.engine_state.ctrlc.clone();
-            let stream = ListStream::from_stream(vals.into_iter(), ctrlc);
+            let stream = ListStream::new(vals.into_iter(), span, ctrlc);
             input.data = PipelineData::Empty;
 
             handle_row_stream(input, cfg, stream, metadata)
@@ -394,10 +394,6 @@ fn handle_table_command(
             input.data = PipelineData::Empty;
             handle_record(input, cfg, val.into_owned())
         }
-        PipelineData::Value(Value::LazyRecord { val, .. }, ..) => {
-            input.data = val.collect()?.into_pipeline_data();
-            handle_table_command(input, cfg)
-        }
         PipelineData::Value(Value::Error { error, .. }, ..) => {
             // Propagate this error outward, so that it goes to stderr
             // instead of stdout.
@@ -409,7 +405,7 @@ fn handle_table_command(
         }
         PipelineData::Value(Value::Range { val, .. }, metadata) => {
             let ctrlc = input.engine_state.ctrlc.clone();
-            let stream = ListStream::from_stream(val.into_range_iter(span, ctrlc.clone()), ctrlc);
+            let stream = ListStream::new(val.into_range_iter(span, ctrlc), span, None);
             input.data = PipelineData::Empty;
             handle_row_stream(input, cfg, stream, metadata)
         }
@@ -417,6 +413,70 @@ fn handle_table_command(
     }
 }
 
+fn pretty_hex_stream(stream: ByteStream, span: Span) -> ByteStream {
+    let mut cfg = HexConfig {
+        // We are going to render the title manually first
+        title: true,
+        // If building on 32-bit, the stream size might be bigger than a usize
+        length: stream.known_size().and_then(|sz| sz.try_into().ok()),
+        ..HexConfig::default()
+    };
+
+    // This won't really work for us
+    debug_assert!(cfg.width > 0, "the default hex config width was zero");
+
+    let mut read_buf = Vec::with_capacity(cfg.width);
+
+    let mut reader = if let Some(reader) = stream.reader() {
+        reader
+    } else {
+        // No stream to read from
+        return ByteStream::read_string("".into(), span, None);
+    };
+
+    ByteStream::from_fn(span, None, ByteStreamType::String, move |buffer| {
+        // Turn the buffer into a String we can write to
+        let mut write_buf = std::mem::take(buffer);
+        write_buf.clear();
+        // SAFETY: we just truncated it empty
+        let mut write_buf = unsafe { String::from_utf8_unchecked(write_buf) };
+
+        // Write the title at the beginning
+        if cfg.title {
+            nu_pretty_hex::write_title(&mut write_buf, cfg, true).expect("format error");
+            cfg.title = false;
+
+            // Put the write_buf back into buffer
+            *buffer = write_buf.into_bytes();
+
+            Ok(true)
+        } else {
+            // Read up to `cfg.width` bytes
+            read_buf.clear();
+            (&mut reader)
+                .take(cfg.width as u64)
+                .read_to_end(&mut read_buf)
+                .err_span(span)?;
+
+            if !read_buf.is_empty() {
+                nu_pretty_hex::hex_write(&mut write_buf, &read_buf, cfg, Some(true))
+                    .expect("format error");
+                write_buf.push('\n');
+
+                // Advance the address offset for next time
+                cfg.address_offset += read_buf.len();
+
+                // Put the write_buf back into buffer
+                *buffer = write_buf.into_bytes();
+
+                Ok(true)
+            } else {
+                Ok(false)
+            }
+        }
+    })
+}
+
 fn handle_record(
     input: CmdInput,
     cfg: TableConfig,
@@ -541,7 +601,6 @@ fn handle_row_stream(
             data_source: DataSource::Ls,
         }) => {
             let config = get_config(input.engine_state, input.stack);
-            let ctrlc = ctrlc.clone();
             let ls_colors_env_str = match input.stack.get_env_var(input.engine_state, "LS_COLORS") {
                 Some(v) => Some(env_to_string(
                     "LS_COLORS",
@@ -553,67 +612,55 @@ fn handle_row_stream(
             };
             let ls_colors = get_ls_colors(ls_colors_env_str);
 
-            ListStream::from_stream(
-                stream.map(move |mut x| match &mut x {
-                    Value::Record { val: record, .. } => {
-                        // Only the name column gets special colors, for now
-                        if let Some(value) = record.to_mut().get_mut("name") {
-                            let span = value.span();
-                            if let Value::String { val, .. } = value {
-                                if let Some(val) = render_path_name(val, &config, &ls_colors, span)
-                                {
-                                    *value = val;
-                                }
+            stream.map(move |mut value| {
+                if let Value::Record { val: record, .. } = &mut value {
+                    // Only the name column gets special colors, for now
+                    if let Some(value) = record.to_mut().get_mut("name") {
+                        let span = value.span();
+                        if let Value::String { val, .. } = value {
+                            if let Some(val) = render_path_name(val, &config, &ls_colors, span) {
+                                *value = val;
                             }
                         }
-
-                        x
                     }
-                    _ => x,
-                }),
-                ctrlc,
-            )
+                }
+                value
+            })
         }
         // Next, `to html -l` sources:
         Some(PipelineMetadata {
             data_source: DataSource::HtmlThemes,
         }) => {
-            let ctrlc = ctrlc.clone();
+            stream.map(|mut value| {
+                if let Value::Record { val: record, .. } = &mut value {
+                    for (rec_col, rec_val) in record.to_mut().iter_mut() {
+                        // Every column in the HTML theme table except 'name' is colored
+                        if rec_col != "name" {
+                            continue;
+                        }
+                        // Simple routine to grab the hex code, convert to a style,
+                        // then place it in a new Value::String.
 
-            ListStream::from_stream(
-                stream.map(move |mut x| match &mut x {
-                    Value::Record { val: record, .. } => {
-                        for (rec_col, rec_val) in record.to_mut().iter_mut() {
-                            // Every column in the HTML theme table except 'name' is colored
-                            if rec_col != "name" {
-                                continue;
-                            }
-                            // Simple routine to grab the hex code, convert to a style,
-                            // then place it in a new Value::String.
-
-                            let span = rec_val.span();
-                            if let Value::String { val, .. } = rec_val {
-                                let s = match color_from_hex(val) {
-                                    Ok(c) => match c {
-                                        // .normal() just sets the text foreground color.
-                                        Some(c) => c.normal(),
-                                        None => nu_ansi_term::Style::default(),
-                                    },
-                                    Err(_) => nu_ansi_term::Style::default(),
-                                };
-                                *rec_val = Value::string(
-                                    // Apply the style (ANSI codes) to the string
-                                    s.paint(&*val).to_string(),
-                                    span,
-                                );
-                            }
+                        let span = rec_val.span();
+                        if let Value::String { val, .. } = rec_val {
+                            let s = match color_from_hex(val) {
+                                Ok(c) => match c {
+                                    // .normal() just sets the text foreground color.
+                                    Some(c) => c.normal(),
+                                    None => nu_ansi_term::Style::default(),
+                                },
+                                Err(_) => nu_ansi_term::Style::default(),
+                            };
+                            *rec_val = Value::string(
+                                // Apply the style (ANSI codes) to the string
+                                s.paint(&*val).to_string(),
+                                span,
+                            );
                         }
-                        x
                     }
-                    _ => x,
-                }),
-                ctrlc,
-            )
+                }
+                value
+            })
         }
         _ => stream,
     };
@@ -628,16 +675,9 @@ fn handle_row_stream(
         ctrlc.clone(),
         cfg,
     );
-    let stream = RawStream::new(Box::new(paginator), ctrlc, input.call.head, None);
-
-    Ok(PipelineData::ExternalStream {
-        stdout: Some(stream),
-        stderr: None,
-        exit_code: None,
-        span: input.call.head,
-        metadata: None,
-        trim_end_newline: false,
-    })
+    let stream =
+        ByteStream::from_result_iter(paginator, input.call.head, None, ByteStreamType::String);
+    Ok(PipelineData::ByteStream(stream, None))
 }
 
 fn make_clickable_link(
@@ -666,7 +706,7 @@ fn make_clickable_link(
 
 struct PagingTableCreator {
     head: Span,
-    stream: ListStream,
+    stream: ValueIterator,
     engine_state: EngineState,
     stack: Stack,
     ctrlc: Option<Arc<AtomicBool>>,
@@ -687,7 +727,7 @@ impl PagingTableCreator {
     ) -> Self {
         PagingTableCreator {
             head,
-            stream,
+            stream: stream.into_inner(),
             engine_state,
             stack,
             ctrlc,
@@ -826,7 +866,7 @@ impl Iterator for PagingTableCreator {
 }
 
 fn stream_collect(
-    stream: &mut ListStream,
+    stream: impl Iterator<Item = Value>,
     size: usize,
     ctrlc: Option<Arc<AtomicBool>>,
 ) -> (Vec<Value>, bool) {
@@ -834,7 +874,7 @@ fn stream_collect(
     let mut end = true;
 
     let mut batch = Vec::with_capacity(size);
-    for (i, item) in stream.by_ref().enumerate() {
+    for (i, item) in stream.enumerate() {
         batch.push(item);
 
         // If we've been buffering over a second, go ahead and send out what we have so far
@@ -857,7 +897,7 @@ fn stream_collect(
 }
 
 fn stream_collect_abbriviated(
-    stream: &mut ListStream,
+    stream: impl Iterator<Item = Value>,
     size: usize,
     ctrlc: Option<Arc<AtomicBool>>,
 ) -> (Vec<Value>, usize, bool) {
@@ -870,7 +910,7 @@ fn stream_collect_abbriviated(
         return (vec![], 0, false);
     }
 
-    for item in stream.by_ref() {
+    for item in stream {
         read += 1;
 
         if read <= size {
@@ -942,7 +982,11 @@ fn render_path_name(
 
     // clickable links don't work in remote SSH sessions
     let in_ssh_session = std::env::var("SSH_CLIENT").is_ok();
-    let show_clickable_links = config.show_clickable_links_in_ls && !in_ssh_session && has_metadata;
+    //TODO: Deprecated show_clickable_links_in_ls in favor of shell_integration_osc8
+    let show_clickable_links = config.show_clickable_links_in_ls
+        && !in_ssh_session
+        && has_metadata
+        && config.shell_integration_osc8;
 
     let ansi_style = style.map(Style::to_nu_ansi_term_style).unwrap_or_default();
 
