@@ -1,4 +1,5 @@
-use crate::{current_dir, current_dir_str, get_config, get_full_help};
+#[allow(deprecated)]
+use crate::{current_dir, get_config, get_full_help};
 use nu_path::expand_path_with;
 use nu_protocol::{
     ast::{
@@ -8,9 +9,10 @@ use nu_protocol::{
     debugger::DebugContext,
     engine::{Closure, EngineState, Redirection, Stack},
     eval_base::Eval,
-    Config, FromValue, IntoPipelineData, OutDest, PipelineData, ShellError, Span, Spanned, Type,
-    Value, VarId, ENV_VARIABLE_ID,
+    ByteStreamSource, Config, FromValue, IntoPipelineData, OutDest, PipelineData, ShellError, Span,
+    Spanned, Type, Value, VarId, ENV_VARIABLE_ID,
 };
+use nu_utils::IgnoreCaseExt;
 use std::{borrow::Cow, fs::OpenOptions, path::PathBuf};
 
 pub fn eval_call<D: DebugContext>(
@@ -25,19 +27,9 @@ pub fn eval_call<D: DebugContext>(
     let decl = engine_state.get_decl(call.decl_id);
 
     if !decl.is_known_external() && call.named_iter().any(|(flag, _, _)| flag.item == "help") {
-        let mut signature = engine_state.get_signature(decl);
-        signature.usage = decl.usage().to_string();
-        signature.extra_usage = decl.extra_usage().to_string();
-
-        let full_help = get_full_help(
-            &signature,
-            &decl.examples(),
-            engine_state,
-            caller_stack,
-            decl.is_parser_keyword(),
-        );
-        Ok(Value::string(full_help, call.head).into_pipeline_data())
-    } else if let Some(block_id) = decl.get_block_id() {
+        let help = get_full_help(decl, engine_state, caller_stack);
+        Ok(Value::string(help, call.head).into_pipeline_data())
+    } else if let Some(block_id) = decl.block_id() {
         let block = engine_state.get_block(block_id);
 
         let mut callee_stack = caller_stack.gather_captures(engine_state, &block.captures);
@@ -207,7 +199,6 @@ pub fn redirect_env(engine_state: &EngineState, caller_stack: &mut Stack, callee
     }
 }
 
-#[allow(clippy::too_many_arguments)]
 fn eval_external(
     engine_state: &EngineState,
     stack: &mut Stack,
@@ -282,7 +273,7 @@ pub fn eval_expression_with_input<D: DebugContext>(
                     let stack = &mut stack.start_capture();
                     // FIXME: protect this collect with ctrl-c
                     input = eval_subexpression::<D>(engine_state, stack, block, input)?
-                        .into_value(*span)
+                        .into_value(*span)?
                         .follow_cell_path(&full_cell_path.tail, false)?
                         .into_pipeline_data()
                 } else {
@@ -299,7 +290,7 @@ pub fn eval_expression_with_input<D: DebugContext>(
         }
     };
 
-    // If input is PipelineData::ExternalStream,
+    // If input an external command,
     // then `might_consume_external_result` will consume `stderr` if `stdout` is `None`.
     // This should not happen if the user wants to capture stderr.
     if !matches!(stack.stdout(), OutDest::Pipe | OutDest::Capture)
@@ -307,15 +298,10 @@ pub fn eval_expression_with_input<D: DebugContext>(
     {
         Ok((input, false))
     } else {
-        Ok(might_consume_external_result(input))
+        input.check_external_failed()
     }
 }
 
-// Try to catch and detect if external command runs to failed.
-fn might_consume_external_result(input: PipelineData) -> (PipelineData, bool) {
-    input.check_external_failed()
-}
-
 fn eval_redirection<D: DebugContext>(
     engine_state: &EngineState,
     stack: &mut Stack,
@@ -324,6 +310,7 @@ fn eval_redirection<D: DebugContext>(
 ) -> Result<Redirection, ShellError> {
     match target {
         RedirectionTarget::File { expr, append, .. } => {
+            #[allow(deprecated)]
             let cwd = current_dir(engine_state, stack)?;
             let value = eval_expression::<D>(engine_state, stack, expr)?;
             let path = Spanned::<PathBuf>::from_value(value)?.item;
@@ -337,7 +324,13 @@ fn eval_redirection<D: DebugContext>(
             }
             Ok(Redirection::file(options.create(true).open(path)?))
         }
-        RedirectionTarget::Pipe { .. } => Ok(Redirection::Pipe(next_out.unwrap_or(OutDest::Pipe))),
+        RedirectionTarget::Pipe { .. } => {
+            let dest = match next_out {
+                None | Some(OutDest::Capture) => OutDest::Pipe,
+                Some(next) => next,
+            };
+            Ok(Redirection::Pipe(dest))
+        }
     }
 }
 
@@ -364,11 +357,12 @@ fn eval_element_redirection<D: DebugContext>(
             } => {
                 let stderr = eval_redirection::<D>(engine_state, stack, target, None)?;
                 if matches!(stderr, Redirection::Pipe(OutDest::Pipe)) {
+                    let dest = match next_out {
+                        None | Some(OutDest::Capture) => OutDest::Pipe,
+                        Some(next) => next,
+                    };
                     // e>| redirection, don't override current stack `stdout`
-                    Ok((
-                        None,
-                        Some(next_out.map(Redirection::Pipe).unwrap_or(stderr)),
-                    ))
+                    Ok((None, Some(Redirection::Pipe(dest))))
                 } else {
                     Ok((next_out.map(Redirection::Pipe), Some(stderr)))
                 }
@@ -400,10 +394,17 @@ fn eval_element_with_input_inner<D: DebugContext>(
     element: &PipelineElement,
     input: PipelineData,
 ) -> Result<(PipelineData, bool), ShellError> {
-    let (data, ok) = eval_expression_with_input::<D>(engine_state, stack, &element.expr, input)?;
+    let (data, failed) =
+        eval_expression_with_input::<D>(engine_state, stack, &element.expr, input)?;
 
-    if !matches!(data, PipelineData::ExternalStream { .. }) {
-        if let Some(redirection) = element.redirection.as_ref() {
+    if let Some(redirection) = element.redirection.as_ref() {
+        let is_external = if let PipelineData::ByteStream(stream, ..) = &data {
+            matches!(stream.source(), ByteStreamSource::Child(..))
+        } else {
+            false
+        };
+
+        if !is_external {
             match redirection {
                 &PipelineRedirection::Single {
                     source: RedirectionSource::Stderr,
@@ -414,8 +415,8 @@ fn eval_element_with_input_inner<D: DebugContext>(
                     ..
                 } => {
                     return Err(ShellError::GenericError {
-                        error: "`e>|` only works with external streams".into(),
-                        msg: "`e>|` only works on external streams".into(),
+                        error: "`e>|` only works on external commands".into(),
+                        msg: "`e>|` only works on external commands".into(),
                         span: Some(span),
                         help: None,
                         inner: vec![],
@@ -426,8 +427,8 @@ fn eval_element_with_input_inner<D: DebugContext>(
                     target: RedirectionTarget::Pipe { span },
                 } => {
                     return Err(ShellError::GenericError {
-                        error: "`o+e>|` only works with external streams".into(),
-                        msg: "`o+e>|` only works on external streams".into(),
+                        error: "`o+e>|` only works on external commands".into(),
+                        msg: "`o+e>|` only works on external commands".into(),
                         span: Some(span),
                         help: None,
                         inner: vec![],
@@ -438,15 +439,33 @@ fn eval_element_with_input_inner<D: DebugContext>(
         }
     }
 
-    let data = if matches!(stack.pipe_stdout(), Some(OutDest::File(_)))
-        && !matches!(stack.pipe_stderr(), Some(OutDest::Pipe))
-    {
-        data.write_to_out_dests(engine_state, stack)?
-    } else {
-        data
+    let has_stdout_file = matches!(stack.pipe_stdout(), Some(OutDest::File(_)));
+
+    let data = match &data {
+        PipelineData::Value(..) | PipelineData::ListStream(..) => {
+            if has_stdout_file {
+                data.write_to_out_dests(engine_state, stack)?;
+                PipelineData::Empty
+            } else {
+                data
+            }
+        }
+        PipelineData::ByteStream(stream, ..) => {
+            let write = match stream.source() {
+                ByteStreamSource::Read(_) | ByteStreamSource::File(_) => has_stdout_file,
+                ByteStreamSource::Child(_) => false,
+            };
+            if write {
+                data.write_to_out_dests(engine_state, stack)?;
+                PipelineData::Empty
+            } else {
+                data
+            }
+        }
+        PipelineData::Empty => PipelineData::Empty,
     };
 
-    Ok((data, ok))
+    Ok((data, failed))
 }
 
 fn eval_element_with_input<D: DebugContext>(
@@ -456,12 +475,18 @@ fn eval_element_with_input<D: DebugContext>(
     input: PipelineData,
 ) -> Result<(PipelineData, bool), ShellError> {
     D::enter_element(engine_state, element);
-
-    let result = eval_element_with_input_inner::<D>(engine_state, stack, element, input);
-
-    D::leave_element(engine_state, element, &result);
-
-    result
+    match eval_element_with_input_inner::<D>(engine_state, stack, element, input) {
+        Ok((data, failed)) => {
+            let res = Ok(data);
+            D::leave_element(engine_state, element, &res);
+            res.map(|data| (data, failed))
+        }
+        Err(err) => {
+            let res = Err(err);
+            D::leave_element(engine_state, element, &res);
+            res.map(|data| (data, false))
+        }
+    }
 }
 
 pub fn eval_block_with_early_return<D: DebugContext>(
@@ -545,17 +570,20 @@ pub fn eval_block<D: DebugContext>(
             }
             input = PipelineData::Empty;
             match output {
-                stream @ PipelineData::ExternalStream { .. } => {
-                    let exit_code = stream.drain_with_exit_code()?;
-                    stack.add_env_var(
-                        "LAST_EXIT_CODE".into(),
-                        Value::int(exit_code, last.expr.span),
-                    );
-                    if exit_code != 0 {
-                        break;
+                PipelineData::ByteStream(stream, ..) => {
+                    let span = stream.span();
+                    let status = stream.drain()?;
+                    if let Some(status) = status {
+                        stack.add_env_var(
+                            "LAST_EXIT_CODE".into(),
+                            Value::int(status.code().into(), span),
+                        );
+                        if status.code() != 0 {
+                            break;
+                        }
                     }
                 }
-                PipelineData::ListStream(stream, _) => {
+                PipelineData::ListStream(stream, ..) => {
                     stream.drain()?;
                 }
                 PipelineData::Value(..) | PipelineData::Empty => {}
@@ -632,7 +660,7 @@ impl Eval for EvalRuntime {
         if quoted {
             Ok(Value::string(path, span))
         } else {
-            let cwd = current_dir_str(engine_state, stack)?;
+            let cwd = engine_state.cwd(Some(stack))?;
             let path = expand_path_with(path, cwd, true);
 
             Ok(Value::string(path.to_string_lossy(), span))
@@ -651,7 +679,7 @@ impl Eval for EvalRuntime {
         } else if quoted {
             Ok(Value::string(path, span))
         } else {
-            let cwd = current_dir_str(engine_state, stack)?;
+            let cwd = engine_state.cwd(Some(stack)).unwrap_or_default();
             let path = expand_path_with(path, cwd, true);
 
             Ok(Value::string(path.to_string_lossy(), span))
@@ -674,7 +702,7 @@ impl Eval for EvalRuntime {
         _: Span,
     ) -> Result<Value, ShellError> {
         // FIXME: protect this collect with ctrl-c
-        Ok(eval_call::<D>(engine_state, stack, call, PipelineData::empty())?.into_value(call.head))
+        eval_call::<D>(engine_state, stack, call, PipelineData::empty())?.into_value(call.head)
     }
 
     fn eval_external_call(
@@ -686,7 +714,7 @@ impl Eval for EvalRuntime {
     ) -> Result<Value, ShellError> {
         let span = head.span;
         // FIXME: protect this collect with ctrl-c
-        Ok(eval_external(engine_state, stack, head, args, PipelineData::empty())?.into_value(span))
+        eval_external(engine_state, stack, head, args, PipelineData::empty())?.into_value(span)
     }
 
     fn eval_subexpression<D: DebugContext>(
@@ -696,12 +724,8 @@ impl Eval for EvalRuntime {
         span: Span,
     ) -> Result<Value, ShellError> {
         let block = engine_state.get_block(block_id);
-
         // FIXME: protect this collect with ctrl-c
-        Ok(
-            eval_subexpression::<D>(engine_state, stack, block, PipelineData::empty())?
-                .into_value(span),
-        )
+        eval_subexpression::<D>(engine_state, stack, block, PipelineData::empty())?.into_value(span)
     }
 
     fn regex_match(
@@ -769,40 +793,48 @@ impl Eval for EvalRuntime {
                         if is_env || engine_state.get_var(*var_id).mutable {
                             let mut lhs =
                                 eval_expression::<D>(engine_state, stack, &cell_path.head)?;
-
-                            lhs.upsert_data_at_cell_path(&cell_path.tail, rhs)?;
                             if is_env {
+                                // Reject attempts to assign to the entire $env
                                 if cell_path.tail.is_empty() {
                                     return Err(ShellError::CannotReplaceEnv {
                                         span: cell_path.head.span,
                                     });
                                 }
 
-                                // The special $env treatment: for something like $env.config.history.max_size = 2000,
-                                // get $env.config (or whichever one it is) AFTER the above mutation, and set it
-                                // as the "config" environment variable.
-                                let vardata =
-                                    lhs.follow_cell_path(&[cell_path.tail[0].clone()], false)?;
-                                match &cell_path.tail[0] {
-                                    PathMember::String { val, span, .. } => {
-                                        if val == "FILE_PWD"
-                                            || val == "CURRENT_FILE"
-                                            || val == "PWD"
-                                        {
-                                            return Err(ShellError::AutomaticEnvVarSetManually {
-                                                envvar_name: val.to_string(),
-                                                span: *span,
-                                            });
-                                        } else {
-                                            stack.add_env_var(val.to_string(), vardata);
-                                        }
-                                    }
-                                    // In case someone really wants an integer env-var
-                                    PathMember::Int { val, .. } => {
-                                        stack.add_env_var(val.to_string(), vardata);
-                                    }
+                                // Updating environment variables should be case-preserving,
+                                // so we need to figure out the original key before we do anything.
+                                let (key, span) = match &cell_path.tail[0] {
+                                    PathMember::String { val, span, .. } => (val.to_string(), span),
+                                    PathMember::Int { val, span, .. } => (val.to_string(), span),
+                                };
+                                let original_key = if let Value::Record { val: record, .. } = &lhs {
+                                    record
+                                        .iter()
+                                        .rev()
+                                        .map(|(k, _)| k)
+                                        .find(|x| x.eq_ignore_case(&key))
+                                        .cloned()
+                                        .unwrap_or(key)
+                                } else {
+                                    key
+                                };
+
+                                // Retrieve the updated environment value.
+                                lhs.upsert_data_at_cell_path(&cell_path.tail, rhs)?;
+                                let value =
+                                    lhs.follow_cell_path(&[cell_path.tail[0].clone()], true)?;
+
+                                // Reject attempts to set automatic environment variables.
+                                if is_automatic_env_var(&original_key) {
+                                    return Err(ShellError::AutomaticEnvVarSetManually {
+                                        envvar_name: original_key,
+                                        span: *span,
+                                    });
                                 }
+
+                                stack.add_env_var(original_key, value);
                             } else {
+                                lhs.upsert_data_at_cell_path(&cell_path.tail, rhs)?;
                                 stack.add_var(*var_id, lhs);
                             }
                             Ok(Value::nothing(cell_path.head.span))
@@ -854,3 +886,19 @@ impl Eval for EvalRuntime {
         Ok(Value::nothing(expr.span))
     }
 }
+
+/// Returns whether a string, when used as the name of an environment variable,
+/// is considered an automatic environment variable.
+///
+/// An automatic environment variable cannot be assigned to by user code.
+/// Current there are three of them: $env.PWD, $env.FILE_PWD, $env.CURRENT_FILE
+fn is_automatic_env_var(var: &str) -> bool {
+    let names = ["PWD", "FILE_PWD", "CURRENT_FILE"];
+    names.iter().any(|&name| {
+        if cfg!(windows) {
+            name.eq_ignore_case(var)
+        } else {
+            name.eq(var)
+        }
+    })
+}
