@@ -16,7 +16,7 @@ pub fn try_build_table(
     let span = value.span();
     match value {
         Value::List { vals, .. } => try_build_list(vals, ctrlc, config, span, style_computer),
-        Value::Record { val, .. } => try_build_map(*val, span, style_computer, ctrlc, config),
+        Value::Record { val, .. } => try_build_map(&val, span, style_computer, ctrlc, config),
         val if matches!(val, Value::String { .. }) => {
             nu_value_to_string_clean(&val, config, style_computer).0
         }
@@ -25,7 +25,7 @@ pub fn try_build_table(
 }
 
 fn try_build_map(
-    record: Record,
+    record: &Record,
     span: Span,
     style_computer: &StyleComputer,
     ctrlc: Option<Arc<AtomicBool>>,
@@ -42,11 +42,11 @@ fn try_build_map(
         0,
         false,
     );
-    let result = ExpandedTable::new(None, false, String::new()).build_map(&record, opts);
+    let result = ExpandedTable::new(None, false, String::new()).build_map(record, opts);
     match result {
         Ok(Some(result)) => result,
         Ok(None) | Err(_) => {
-            nu_value_to_string(&Value::record(record, span), config, style_computer).0
+            nu_value_to_string(&Value::record(record.clone(), span), config, style_computer).0
         }
     }
 }
