@@ -1,27 +1,21 @@
 use super::NuSpan;
+use anyhow::Result;
 use nu_engine::get_columns;
-use nu_protocol::{record, ListStream, PipelineData, PipelineMetadata, RawStream, Value};
+use nu_protocol::{record, ByteStream, ListStream, PipelineData, PipelineMetadata, Value};
 use std::collections::HashMap;
 
-pub fn collect_pipeline(input: PipelineData) -> (Vec<String>, Vec<Vec<Value>>) {
+pub fn collect_pipeline(input: PipelineData) -> Result<(Vec<String>, Vec<Vec<Value>>)> {
     match input {
-        PipelineData::Empty => (vec![], vec![]),
+        PipelineData::Empty => Ok((vec![], vec![])),
         PipelineData::Value(value, ..) => collect_input(value),
-        PipelineData::ListStream(stream, ..) => collect_list_stream(stream),
-        PipelineData::ExternalStream {
-            stdout,
-            stderr,
-            exit_code,
-            metadata,
-            span,
-            ..
-        } => collect_external_stream(stdout, stderr, exit_code, metadata, span),
+        PipelineData::ListStream(stream, ..) => Ok(collect_list_stream(stream)),
+        PipelineData::ByteStream(stream, metadata) => Ok(collect_byte_stream(stream, metadata)),
     }
 }
 
-fn collect_list_stream(mut stream: ListStream) -> (Vec<String>, Vec<Vec<Value>>) {
+fn collect_list_stream(stream: ListStream) -> (Vec<String>, Vec<Vec<Value>>) {
     let mut records = vec![];
-    for item in stream.by_ref() {
+    for item in stream {
         records.push(item);
     }
 
@@ -39,56 +33,67 @@ fn collect_list_stream(mut stream: ListStream) -> (Vec<String>, Vec<Vec<Value>>)
     (cols, data)
 }
 
-fn collect_external_stream(
-    stdout: Option<RawStream>,
-    stderr: Option<RawStream>,
-    exit_code: Option<ListStream>,
+fn collect_byte_stream(
+    stream: ByteStream,
     metadata: Option<PipelineMetadata>,
-    span: NuSpan,
 ) -> (Vec<String>, Vec<Vec<Value>>) {
+    let span = stream.span();
+
     let mut columns = vec![];
     let mut data = vec![];
-    if let Some(stdout) = stdout {
-        let value = stdout.into_string().map_or_else(
-            |error| Value::error(error, span),
-            |string| Value::string(string.item, span),
-        );
 
-        columns.push(String::from("stdout"));
-        data.push(value);
-    }
-    if let Some(stderr) = stderr {
-        let value = stderr.into_string().map_or_else(
-            |error| Value::error(error, span),
-            |string| Value::string(string.item, span),
-        );
+    match stream.into_child() {
+        Ok(child) => match child.wait_with_output() {
+            Ok(output) => {
+                let exit_code = output.exit_status.code();
+                if let Some(stdout) = output.stdout {
+                    columns.push(String::from("stdout"));
+                    data.push(string_or_binary(stdout, span));
+                }
+                if let Some(stderr) = output.stderr {
+                    columns.push(String::from("stderr"));
+                    data.push(string_or_binary(stderr, span));
+                }
+                columns.push(String::from("exit_code"));
+                data.push(Value::int(exit_code.into(), span));
+            }
+            Err(err) => {
+                columns.push("".into());
+                data.push(Value::error(err, span));
+            }
+        },
+        Err(stream) => {
+            let value = stream
+                .into_value()
+                .unwrap_or_else(|err| Value::error(err, span));
 
-        columns.push(String::from("stderr"));
-        data.push(value);
+            columns.push("".into());
+            data.push(value);
+        }
     }
-    if let Some(exit_code) = exit_code {
-        let list = exit_code.collect::<Vec<_>>();
-        let val = Value::list(list, span);
 
-        columns.push(String::from("exit_code"));
-        data.push(val);
-    }
     if metadata.is_some() {
         let val = Value::record(record! { "data_source" => Value::string("ls", span) }, span);
-
         columns.push(String::from("metadata"));
         data.push(val);
     }
     (columns, vec![data])
 }
 
+fn string_or_binary(bytes: Vec<u8>, span: NuSpan) -> Value {
+    match String::from_utf8(bytes) {
+        Ok(str) => Value::string(str, span),
+        Err(err) => Value::binary(err.into_bytes(), span),
+    }
+}
+
 /// Try to build column names and a table grid.
-pub fn collect_input(value: Value) -> (Vec<String>, Vec<Vec<Value>>) {
+pub fn collect_input(value: Value) -> Result<(Vec<String>, Vec<Vec<Value>>)> {
     let span = value.span();
     match value {
         Value::Record { val: record, .. } => {
             let (key, val) = record.into_owned().into_iter().unzip();
-            (key, vec![val])
+            Ok((key, vec![val]))
         }
         Value::List { vals, .. } => {
             let mut columns = get_columns(&vals);
@@ -98,7 +103,7 @@ pub fn collect_input(value: Value) -> (Vec<String>, Vec<Vec<Value>>) {
                 columns = vec![String::from("")];
             }
 
-            (columns, data)
+            Ok((columns, data))
         }
         Value::String { val, .. } => {
             let lines = val
@@ -107,17 +112,14 @@ pub fn collect_input(value: Value) -> (Vec<String>, Vec<Vec<Value>>) {
                 .map(|val| vec![val])
                 .collect();
 
-            (vec![String::from("")], lines)
+            Ok((vec![String::from("")], lines))
         }
-        Value::LazyRecord { val, .. } => match val.collect() {
-            Ok(value) => collect_input(value),
-            Err(_) => (
-                vec![String::from("")],
-                vec![vec![Value::lazy_record(val, span)]],
-            ),
-        },
-        Value::Nothing { .. } => (vec![], vec![]),
-        value => (vec![String::from("")], vec![vec![value]]),
+        Value::Nothing { .. } => Ok((vec![], vec![])),
+        Value::Custom { val, .. } => {
+            let materialized = val.to_base_value(span)?;
+            collect_input(materialized)
+        }
+        value => Ok((vec![String::from("")], vec![vec![value]])),
     }
 }
 
