@@ -32,25 +32,10 @@ impl XYCursor {
         self.x.index()
     }
 
-    #[allow(dead_code)]
-    pub fn row_offset(&self) -> usize {
-        self.y.offset()
-    }
-
-    #[allow(dead_code)]
-    pub fn column_limit(&self) -> usize {
-        self.x.end()
-    }
-
     pub fn row_limit(&self) -> usize {
         self.y.end()
     }
 
-    #[allow(dead_code)]
-    pub fn column_offset(&self) -> usize {
-        self.x.offset()
-    }
-
     pub fn row_starts_at(&self) -> usize {
         self.y.starts_at()
     }
@@ -67,11 +52,6 @@ impl XYCursor {
         self.x.offset()
     }
 
-    #[allow(dead_code)]
-    pub fn row_window_size(&self) -> usize {
-        self.y.window()
-    }
-
     pub fn column_window_size(&self) -> usize {
         self.x.window()
     }
@@ -80,11 +60,6 @@ impl XYCursor {
         self.y.next(1)
     }
 
-    #[allow(dead_code)]
-    pub fn next_row_by(&mut self, i: usize) -> bool {
-        self.y.next(i)
-    }
-
     pub fn next_row_page(&mut self) -> bool {
         self.y.next_window()
     }
@@ -101,11 +76,6 @@ impl XYCursor {
         self.y.prev(1)
     }
 
-    #[allow(dead_code)]
-    pub fn prev_row_by(&mut self, i: usize) -> bool {
-        self.y.prev(i)
-    }
-
     pub fn prev_row_page(&mut self) -> bool {
         self.y.prev_window()
     }
