@@ -1,6 +1,6 @@
 use nu_parser::*;
 use nu_protocol::{
-    ast::{Argument, Call, Expr, PathMember, Range},
+    ast::{Argument, Call, Expr, ExternalArgument, PathMember, Range},
     engine::{Command, EngineState, Stack, StateWorkingSet},
     ParseError, PipelineData, ShellError, Signature, Span, SyntaxShape,
 };
@@ -727,6 +727,45 @@ fn test_redirection_with_letmut(#[case] phase: &[u8]) {
     ));
 }
 
+#[rstest]
+#[case(b"o>")]
+#[case(b"o>>")]
+#[case(b"e>")]
+#[case(b"e>>")]
+#[case(b"o+e>")]
+#[case(b"o+e>>")]
+#[case(b"e>|")]
+#[case(b"o+e>|")]
+#[case(b"|o>")]
+#[case(b"|o>>")]
+#[case(b"|e>")]
+#[case(b"|e>>")]
+#[case(b"|o+e>")]
+#[case(b"|o+e>>")]
+#[case(b"|e>|")]
+#[case(b"|o+e>|")]
+#[case(b"e> file")]
+#[case(b"e>> file")]
+#[case(b"o> file")]
+#[case(b"o>> file")]
+#[case(b"o+e> file")]
+#[case(b"o+e>> file")]
+#[case(b"|e> file")]
+#[case(b"|e>> file")]
+#[case(b"|o> file")]
+#[case(b"|o>> file")]
+#[case(b"|o+e> file")]
+#[case(b"|o+e>> file")]
+fn test_redirecting_nothing(#[case] text: &[u8]) {
+    let engine_state = EngineState::new();
+    let mut working_set = StateWorkingSet::new(&engine_state);
+    let _ = parse(&mut working_set, None, text, true);
+    assert!(matches!(
+        working_set.parse_errors.first(),
+        Some(ParseError::UnexpectedRedirection { .. })
+    ));
+}
+
 #[test]
 fn test_nothing_comparison_neq() {
     let engine_state = EngineState::new();
@@ -926,6 +965,28 @@ mod string {
             assert!(working_set.parse_errors.is_empty());
         }
     }
+
+    #[test]
+    fn parse_raw_string_as_external_argument() {
+        let engine_state = EngineState::new();
+        let mut working_set = StateWorkingSet::new(&engine_state);
+
+        let block = parse(&mut working_set, None, b"^echo r#'text'#", true);
+
+        assert!(working_set.parse_errors.is_empty());
+        assert_eq!(block.len(), 1);
+        let pipeline = &block.pipelines[0];
+        assert_eq!(pipeline.len(), 1);
+        let element = &pipeline.elements[0];
+        assert!(element.redirection.is_none());
+        if let Expr::ExternalCall(_, args) = &element.expr.expr {
+            if let [ExternalArgument::Regular(expr)] = args.as_ref() {
+                assert_eq!(expr.expr, Expr::RawString("text".into()));
+                return;
+            }
+        }
+        panic!("wrong expression: {:?}", element.expr.expr)
+    }
 }
 
 #[rstest]
