@@ -11,8 +11,8 @@ use nu_plugin_protocol::{
     PluginOutput, ProtocolInfo, StreamId, StreamMessage,
 };
 use nu_protocol::{
-    ast::Operator, CustomValue, IntoInterruptiblePipelineData, IntoSpanned, ListStream,
-    PipelineData, PluginSignature, ShellError, Span, Spanned, Value,
+    ast::Operator, CustomValue, IntoSpanned, PipelineData, PluginSignature, ShellError, Span,
+    Spanned, Value,
 };
 use std::{
     collections::{btree_map, BTreeMap},
@@ -519,8 +519,8 @@ impl InterfaceManager for PluginInterfaceManager {
                     .map_data(|data| {
                         let ctrlc = self.get_ctrlc(id)?;
 
-                        // Register the streams in the response
-                        for stream_id in data.stream_ids() {
+                        // Register the stream in the response
+                        if let Some(stream_id) = data.stream_id() {
                             self.recv_stream_started(id, stream_id);
                         }
 
@@ -592,16 +592,17 @@ impl InterfaceManager for PluginInterfaceManager {
                 })?;
                 Ok(data)
             }
-            PipelineData::ListStream(ListStream { stream, ctrlc, .. }, meta) => {
+            PipelineData::ListStream(stream, meta) => {
                 let source = self.state.source.clone();
-                Ok(stream
-                    .map(move |mut value| {
+                Ok(PipelineData::ListStream(
+                    stream.map(move |mut value| {
                         let _ = PluginCustomValueWithSource::add_source_in(&mut value, &source);
                         value
-                    })
-                    .into_pipeline_data_with_metadata(meta, ctrlc))
+                    }),
+                    meta,
+                ))
             }
-            PipelineData::Empty | PipelineData::ExternalStream { .. } => Ok(data),
+            PipelineData::Empty | PipelineData::ByteStream(..) => Ok(data),
         }
     }
 
@@ -952,7 +953,7 @@ impl PluginInterface {
 
         let call = PluginCall::CustomValueOp(value.map(|cv| cv.without_source()), op);
         match self.plugin_call(call, None)? {
-            PluginCallResponse::PipelineData(out_data) => Ok(out_data.into_value(span)),
+            PluginCallResponse::PipelineData(out_data) => out_data.into_value(span),
             PluginCallResponse::Error(err) => Err(err.into()),
             _ => Err(ShellError::PluginFailedToDecode {
                 msg: format!("Received unexpected response to custom value {op_name}() call"),
@@ -1076,20 +1077,21 @@ impl Interface for PluginInterface {
                 state.prepare_value(&mut value, &self.state.source)?;
                 Ok(PipelineData::Value(value, meta))
             }
-            PipelineData::ListStream(ListStream { stream, ctrlc, .. }, meta) => {
+            PipelineData::ListStream(stream, meta) => {
                 let source = self.state.source.clone();
                 let state = state.clone();
-                Ok(stream
-                    .map(move |mut value| {
+                Ok(PipelineData::ListStream(
+                    stream.map(move |mut value| {
                         match state.prepare_value(&mut value, &source) {
                             Ok(()) => value,
                             // Put the error in the stream instead
                             Err(err) => Value::error(err, value.span()),
                         }
-                    })
-                    .into_pipeline_data_with_metadata(meta, ctrlc))
+                    }),
+                    meta,
+                ))
             }
-            PipelineData::Empty | PipelineData::ExternalStream { .. } => Ok(data),
+            PipelineData::Empty | PipelineData::ByteStream(..) => Ok(data),
         }
     }
 }
