@@ -9,16 +9,16 @@ use crate::{
 use nu_plugin_core::{interface_test_util::TestCase, Interface, InterfaceManager};
 use nu_plugin_protocol::{
     test_util::{expected_test_custom_value, test_plugin_custom_value},
-    CallInfo, CustomValueOp, EngineCall, EngineCallResponse, EvaluatedCall, ExternalStreamInfo,
+    ByteStreamInfo, CallInfo, CustomValueOp, EngineCall, EngineCallResponse, EvaluatedCall,
     ListStreamInfo, PipelineDataHeader, PluginCall, PluginCallId, PluginCallResponse,
-    PluginCustomValue, PluginInput, PluginOutput, Protocol, ProtocolInfo, RawStreamInfo,
-    StreamData, StreamMessage,
+    PluginCustomValue, PluginInput, PluginOutput, Protocol, ProtocolInfo, StreamData,
+    StreamMessage,
 };
 use nu_protocol::{
     ast::{Math, Operator},
     engine::Closure,
-    CustomValue, IntoInterruptiblePipelineData, IntoSpanned, PipelineData, PluginSignature,
-    ShellError, Span, Spanned, Value,
+    ByteStreamType, CustomValue, IntoInterruptiblePipelineData, IntoSpanned, PipelineData,
+    PluginSignature, ShellError, Span, Spanned, Value,
 };
 use serde::{Deserialize, Serialize};
 use std::{
@@ -52,7 +52,10 @@ fn manager_consume_all_exits_after_streams_and_interfaces_are_dropped() -> Resul
 
     // Create a stream...
     let stream = manager.read_pipeline_data(
-        PipelineDataHeader::ListStream(ListStreamInfo { id: 0 }),
+        PipelineDataHeader::ListStream(ListStreamInfo {
+            id: 0,
+            span: Span::test_data(),
+        }),
         None,
     )?;
 
@@ -105,7 +108,10 @@ fn manager_consume_all_propagates_io_error_to_readers() -> Result<(), ShellError
     test.set_read_error(test_io_error());
 
     let stream = manager.read_pipeline_data(
-        PipelineDataHeader::ListStream(ListStreamInfo { id: 0 }),
+        PipelineDataHeader::ListStream(ListStreamInfo {
+            id: 0,
+            span: Span::test_data(),
+        }),
         None,
     )?;
 
@@ -148,16 +154,10 @@ fn manager_consume_all_propagates_message_error_to_readers() -> Result<(), Shell
     test.add(invalid_output());
 
     let stream = manager.read_pipeline_data(
-        PipelineDataHeader::ExternalStream(ExternalStreamInfo {
+        PipelineDataHeader::ByteStream(ByteStreamInfo {
+            id: 0,
             span: Span::test_data(),
-            stdout: Some(RawStreamInfo {
-                id: 0,
-                is_binary: false,
-                known_size: None,
-            }),
-            stderr: None,
-            exit_code: None,
-            trim_end_newline: false,
+            type_: ByteStreamType::Unknown,
         }),
         None,
     )?;
@@ -331,7 +331,10 @@ fn manager_consume_call_response_forwards_to_subscriber_with_pipeline_data(
 
     manager.consume(PluginOutput::CallResponse(
         0,
-        PluginCallResponse::PipelineData(PipelineDataHeader::ListStream(ListStreamInfo { id: 0 })),
+        PluginCallResponse::PipelineData(PipelineDataHeader::ListStream(ListStreamInfo {
+            id: 0,
+            span: Span::test_data(),
+        })),
     ))?;
 
     for i in 0..2 {
@@ -369,27 +372,20 @@ fn manager_consume_call_response_registers_streams() -> Result<(), ShellError> {
         fake_plugin_call(&mut manager, n);
     }
 
-    // Check list streams, external streams
+    // Check list streams, byte streams
     manager.consume(PluginOutput::CallResponse(
         0,
-        PluginCallResponse::PipelineData(PipelineDataHeader::ListStream(ListStreamInfo { id: 0 })),
+        PluginCallResponse::PipelineData(PipelineDataHeader::ListStream(ListStreamInfo {
+            id: 0,
+            span: Span::test_data(),
+        })),
     ))?;
     manager.consume(PluginOutput::CallResponse(
         1,
-        PluginCallResponse::PipelineData(PipelineDataHeader::ExternalStream(ExternalStreamInfo {
+        PluginCallResponse::PipelineData(PipelineDataHeader::ByteStream(ByteStreamInfo {
+            id: 1,
             span: Span::test_data(),
-            stdout: Some(RawStreamInfo {
-                id: 1,
-                is_binary: false,
-                known_size: None,
-            }),
-            stderr: Some(RawStreamInfo {
-                id: 2,
-                is_binary: false,
-                known_size: None,
-            }),
-            exit_code: Some(ListStreamInfo { id: 3 }),
-            trim_end_newline: false,
+            type_: ByteStreamType::Unknown,
         })),
     ))?;
 
@@ -408,22 +404,20 @@ fn manager_consume_call_response_registers_streams() -> Result<(), ShellError> {
         "plugin_call_input_streams[0] should be Some(0)"
     );
 
-    // ExternalStream should have three
+    // ByteStream should have one
     if let Some(sub) = manager.plugin_call_states.get(&1) {
         assert_eq!(
-            3, sub.remaining_streams_to_read,
-            "ExternalStream remaining_streams_to_read should be 3"
+            1, sub.remaining_streams_to_read,
+            "ByteStream remaining_streams_to_read should be 1"
         );
     } else {
-        panic!("failed to find subscription for ExternalStream (1), maybe it was removed");
-    }
-    for n in [1, 2, 3] {
-        assert_eq!(
-            Some(&1),
-            manager.plugin_call_input_streams.get(&n),
-            "plugin_call_input_streams[{n}] should be Some(1)"
-        );
+        panic!("failed to find subscription for ByteStream (1), maybe it was removed");
     }
+    assert_eq!(
+        Some(&1),
+        manager.plugin_call_input_streams.get(&1),
+        "plugin_call_input_streams[1] should be Some(1)"
+    );
 
     Ok(())
 }
@@ -448,7 +442,10 @@ fn manager_consume_engine_call_forwards_to_subscriber_with_pipeline_data() -> Re
                 span: Span::test_data(),
             },
             positional: vec![],
-            input: PipelineDataHeader::ListStream(ListStreamInfo { id: 2 }),
+            input: PipelineDataHeader::ListStream(ListStreamInfo {
+                id: 2,
+                span: Span::test_data(),
+            }),
             redirect_stdout: false,
             redirect_stderr: false,
         },
@@ -681,7 +678,7 @@ fn manager_prepare_pipeline_data_adds_source_to_list_streams() -> Result<(), She
         [Value::test_custom_value(Box::new(
             test_plugin_custom_value(),
         ))]
-        .into_pipeline_data(None),
+        .into_pipeline_data(Span::test_data(), None),
     )?;
 
     let value = data
@@ -855,7 +852,7 @@ fn interface_write_plugin_call_writes_run_with_stream_input() -> Result<(), Shel
                 positional: vec![],
                 named: vec![],
             },
-            input: values.clone().into_pipeline_data(None),
+            input: values.clone().into_pipeline_data(Span::test_data(), None),
         }),
         None,
     )?;
@@ -1069,7 +1066,7 @@ fn interface_run() -> Result<(), ShellError> {
 
     assert_eq!(
         Value::test_int(number),
-        result.into_value(Span::test_data())
+        result.into_value(Span::test_data())?,
     );
     assert!(test.has_unconsumed_write());
     Ok(())
@@ -1118,7 +1115,7 @@ fn interface_prepare_pipeline_data_accepts_normal_values() -> Result<(), ShellEr
         match interface.prepare_pipeline_data(PipelineData::Value(value.clone(), None), &state) {
             Ok(data) => assert_eq!(
                 value.get_type(),
-                data.into_value(Span::test_data()).get_type()
+                data.into_value(Span::test_data())?.get_type(),
             ),
             Err(err) => panic!("failed to accept {value:?}: {err}"),
         }
@@ -1131,7 +1128,10 @@ fn interface_prepare_pipeline_data_accepts_normal_streams() -> Result<(), ShellE
     let interface = TestCase::new().plugin("test").get_interface();
     let values = normal_values(&interface);
     let state = CurrentCallState::default();
-    let data = interface.prepare_pipeline_data(values.clone().into_pipeline_data(None), &state)?;
+    let data = interface.prepare_pipeline_data(
+        values.clone().into_pipeline_data(Span::test_data(), None),
+        &state,
+    )?;
 
     let mut count = 0;
     for (expected_value, actual_value) in values.iter().zip(data) {
@@ -1191,7 +1191,10 @@ fn interface_prepare_pipeline_data_rejects_bad_custom_value_in_a_stream() -> Res
     let interface = TestCase::new().plugin("test").get_interface();
     let values = bad_custom_values();
     let state = CurrentCallState::default();
-    let data = interface.prepare_pipeline_data(values.clone().into_pipeline_data(None), &state)?;
+    let data = interface.prepare_pipeline_data(
+        values.clone().into_pipeline_data(Span::test_data(), None),
+        &state,
+    )?;
 
     let mut count = 0;
     for value in data {
