@@ -80,7 +80,7 @@ fn test_requiring_nu_cmd_lang_commands() -> Result<(), ShellError> {
 
     let result = PluginTest::new("hello", HelloPlugin.into())?
         .eval("do { let greeting = hello; $greeting }")?
-        .into_value(Span::test_data());
+        .into_value(Span::test_data())?;
 
     assert_eq!(Value::test_string("Hello, World!"), result);
 
