@@ -4,10 +4,14 @@ mod cell_path;
 mod expr;
 mod expression;
 mod import_pattern;
+mod keyword;
 mod match_pattern;
 mod operator;
 mod pipeline;
+mod range;
+pub mod table;
 mod unit;
+mod value_with_unit;
 
 pub use block::*;
 pub use call::*;
@@ -15,7 +19,11 @@ pub use cell_path::*;
 pub use expr::*;
 pub use expression::*;
 pub use import_pattern::*;
+pub use keyword::*;
 pub use match_pattern::*;
 pub use operator::*;
 pub use pipeline::*;
+pub use range::*;
+pub use table::Table;
 pub use unit::*;
+pub use value_with_unit::*;
