@@ -1,7 +1,9 @@
 mod identity;
 mod registered;
+mod registry_file;
 mod signature;
 
 pub use identity::*;
 pub use registered::*;
+pub use registry_file::*;
 pub use signature::*;
