@@ -42,6 +42,6 @@ impl SimplePluginCommand for Generate {
 fn test_examples() -> Result<(), nu_protocol::ShellError> {
     use nu_plugin_test_support::PluginTest;
 
-    PluginTest::new("custom_values", crate::CustomValuePlugin.into())?
+    PluginTest::new("custom_values", CustomValuePlugin::new().into())?
         .test_command_examples(&Generate)
 }
