@@ -2,5 +2,5 @@ use nu_plugin::{serve_plugin, JsonSerializer};
 use nu_plugin_query::Query;
 
 fn main() {
-    serve_plugin(&mut Query {}, JsonSerializer {})
+    serve_plugin(&Query {}, JsonSerializer {})
 }
