@@ -39,7 +39,9 @@ pub enum ToStyle {
 
 /// convert an actual Nushell [`Value`] to a raw string representation of the NUON data
 ///
-/// > **Note**
+// WARNING: please leave the following two trailing spaces, they matter for the documentation
+// formatting
+/// > **Note**  
 /// > a [`Span`] can be passed to [`to_nuon`] if there is context available to the caller, e.g. when
 /// > using this function in a command implementation such as [`to nuon`](https://www.nushell.sh/commands/docs/to_nuon.html).
 ///
@@ -97,12 +99,7 @@ fn value_to_string(
                 Ok("false".to_string())
             }
         }
-        Value::CellPath { .. } => Err(ShellError::UnsupportedInput {
-            msg: "cell-paths are currently not nuon-compatible".to_string(),
-            input: "value originates from here".into(),
-            msg_span: span,
-            input_span: v.span(),
-        }),
+        Value::CellPath { val, .. } => Ok(format!("$.{}", val)),
         Value::Custom { .. } => Err(ShellError::UnsupportedInput {
             msg: "custom values are currently not nuon-compatible".to_string(),
             input: "value originates from here".into(),
@@ -179,7 +176,7 @@ fn value_to_string(
             }
         }
         Value::Nothing { .. } => Ok("null".to_string()),
-        Value::Range { val, .. } => match val {
+        Value::Range { val, .. } => match **val {
             Range::IntRange(range) => Ok(range.to_string()),
             Range::FloatRange(range) => {
                 let start =
@@ -221,10 +218,6 @@ fn value_to_string(
                 collection.join(&format!(",{sep}{nl}"))
             ))
         }
-        Value::LazyRecord { val, .. } => {
-            let collected = val.collect()?;
-            value_to_string(&collected, span, depth + 1, indent)
-        }
         // All strings outside data structures are quoted because they are in 'command position'
         // (could be mistaken for commands by the Nu parser)
         Value::String { val, .. } => Ok(escape_quote_string(val)),
