@@ -8,19 +8,22 @@ use log::trace;
 #[cfg(feature = "plugin")]
 use nu_cli::read_plugin_file;
 use nu_cli::{evaluate_commands, evaluate_file, evaluate_repl};
-use nu_protocol::{eval_const::create_nu_constant, PipelineData, Span, NU_VARIABLE_ID};
+use nu_protocol::{
+    engine::{EngineState, Stack},
+    report_error_new, PipelineData, Spanned,
+};
 use nu_utils::utils::perf;
 
 pub(crate) fn run_commands(
-    engine_state: &mut nu_protocol::engine::EngineState,
+    engine_state: &mut EngineState,
     parsed_nu_cli_args: command::NushellCliArgs,
     use_color: bool,
-    commands: &nu_protocol::Spanned<String>,
+    commands: &Spanned<String>,
     input: PipelineData,
     entire_start_time: std::time::Instant,
-) -> Result<(), miette::ErrReport> {
+) {
     trace!("run_commands");
-    let mut stack = nu_protocol::engine::Stack::new();
+    let mut stack = Stack::new();
     let start_time = std::time::Instant::now();
 
     // if the --no-config-file(-n) option is NOT passed, load the plugin file,
@@ -103,18 +106,20 @@ pub(crate) fn run_commands(
     engine_state.set_startup_time(entire_start_time.elapsed().as_nanos() as i64);
 
     // Regenerate the $nu constant to contain the startup time and any other potential updates
-    let nu_const = create_nu_constant(engine_state, commands.span)?;
-    engine_state.set_variable_const_val(NU_VARIABLE_ID, nu_const);
+    engine_state.generate_nu_constant();
 
     let start_time = std::time::Instant::now();
-    let ret_val = evaluate_commands(
+    if let Err(err) = evaluate_commands(
         commands,
         engine_state,
         &mut stack,
         input,
         parsed_nu_cli_args.table_mode,
         parsed_nu_cli_args.no_newline.is_some(),
-    );
+    ) {
+        report_error_new(engine_state, &err);
+        std::process::exit(1);
+    }
     perf(
         "evaluate_commands",
         start_time,
@@ -123,24 +128,18 @@ pub(crate) fn run_commands(
         column!(),
         use_color,
     );
-
-    match ret_val {
-        Ok(Some(exit_code)) => std::process::exit(exit_code as i32),
-        Ok(None) => Ok(()),
-        Err(e) => Err(e),
-    }
 }
 
 pub(crate) fn run_file(
-    engine_state: &mut nu_protocol::engine::EngineState,
+    engine_state: &mut EngineState,
     parsed_nu_cli_args: command::NushellCliArgs,
     use_color: bool,
     script_name: String,
     args_to_script: Vec<String>,
     input: PipelineData,
-) -> Result<(), miette::ErrReport> {
+) {
     trace!("run_file");
-    let mut stack = nu_protocol::engine::Stack::new();
+    let mut stack = Stack::new();
 
     // if the --no-config-file(-n) option is NOT passed, load the plugin file,
     // load the default env file or custom (depending on parsed_nu_cli_args.env_file),
@@ -201,17 +200,19 @@ pub(crate) fn run_file(
     }
 
     // Regenerate the $nu constant to contain the startup time and any other potential updates
-    let nu_const = create_nu_constant(engine_state, input.span().unwrap_or_else(Span::unknown))?;
-    engine_state.set_variable_const_val(NU_VARIABLE_ID, nu_const);
+    engine_state.generate_nu_constant();
 
     let start_time = std::time::Instant::now();
-    let ret_val = evaluate_file(
+    if let Err(err) = evaluate_file(
         script_name,
         &args_to_script,
         engine_state,
         &mut stack,
         input,
-    );
+    ) {
+        report_error_new(engine_state, &err);
+        std::process::exit(1);
+    }
     perf(
         "evaluate_file",
         start_time,
@@ -239,17 +240,15 @@ pub(crate) fn run_file(
         column!(),
         use_color,
     );
-
-    ret_val
 }
 
 pub(crate) fn run_repl(
-    engine_state: &mut nu_protocol::engine::EngineState,
+    engine_state: &mut EngineState,
     parsed_nu_cli_args: command::NushellCliArgs,
     entire_start_time: std::time::Instant,
 ) -> Result<(), miette::ErrReport> {
     trace!("run_repl");
-    let mut stack = nu_protocol::engine::Stack::new();
+    let mut stack = Stack::new();
     let start_time = std::time::Instant::now();
 
     if parsed_nu_cli_args.no_config_file.is_none() {
